@@ -636,7 +636,7 @@ int main ( int argc, char *argv[] )
     char *endptr;
 
 #ifdef DRIVER_DSP    
-    char *pid_str[30];
+    char pid_str[30];
     pid_t esd_pid = 0;
 #endif
     
@@ -1022,7 +1022,6 @@ int main ( int argc, char *argv[] )
     /* For OOM killer */
     esd_pid = getpid();    
     snprintf(pid_str, 29, "/proc/%d/oom_adj", esd_pid);
-//    printf("Opening %s\n", pid_str);    
     itmp = open(pid_str, O_RDWR);
     
     if ( itmp != -1 ) {
@@ -1031,6 +1030,7 @@ int main ( int argc, char *argv[] )
       printf("Can't open %s for adjusting value\n. Giving up!\n", pid_str);
       exit(1);
     }
+    close(itmp);
 #endif
 
     /* until we kill the daemon */
